==> hqsoft_core-0.0.19.tar.gz: lib/core_base/preferences/token_login_preferences.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:hqsoft_core/data_base/data_base.dart';
import 'package:shared_preferences/shared_preferences.dart';

const String _storageKey = "TokenLogin_";

Future<SharedPreferences> _prefs = SharedPreferences.getInstance();

TokenPreferences tokenPreferences = TokenPreferences();

class TokenPreferences {
  /// ----------------------------------------------------------
  /// Generic routine to fetch a preference
  /// ----------------------------------------------------------
  Future<String> _getStringApplicationSavedInformation(String name) async {
    final SharedPreferences prefs = await _prefs;
    return prefs.getString(_storageKey + name) ?? '';
  }

  Future<bool> _getBoolApplicationSavedInformation(String name) async {
    final SharedPreferences prefs = await _prefs;

    return prefs.getBool(_storageKey + name) ?? false;
  }

  Future<int> _getIntApplicationSavedInformation(String name) async {
    final SharedPreferences prefs = await _prefs;
    return prefs.getInt(_storageKey + name) ?? -1;
  }

  Future<bool> _setStringApplicationSavedInformation(
      String name, String value) async {
    final SharedPreferences prefs = await _prefs;

    return prefs.setString(_storageKey + name, value);
  }

  Future<bool> _setBoolApplicationSavedInformation(
      String name, bool value) async {
    final SharedPreferences prefs = await _prefs;

    return prefs.setBool(_storageKey + name, value);
  }

  Future<bool> _setIntApplicationSavedInformation(
      String name, int value) async {
    final SharedPreferences prefs = await _prefs;
    return prefs.setInt(_storageKey + name, value);
  }

  setPreferredResultTokenLogin(ResultTokenLogin resultTokenLogin) async {
    await tokenPreferences
        .setPreferredResultToken(jsonEncode(resultTokenLogin));
    await tokenPreferences.setPreferredToken(resultTokenLogin.token);
    await tokenPreferences.setPreferredIdentity(resultTokenLogin.identity);
    await tokenPreferences.setPreferredPassword(resultTokenLogin.password);
  }

  Future<ResultTokenLogin> getPreferredResultToken() async {
    String resultTokenString = "";
    resultTokenString =
        await _getStringApplicationSavedInformation('resultTokenLogin');
    if (resultTokenString.length == 0) {
      return null;
    }
    ResultTokenLogin resultToken =
        ResultTokenLogin.fromJson(jsonDecode(resultTokenString));
    return resultToken;
  }

  Future<String> getPreferredToken() async {
    return _getStringApplicationSavedInformation('token');
  }

  Future<String> getPreferredTokenFCM() async {
    return _getStringApplicationSavedInformation('tokenFCM');
  }

  Future<int> getPreferredIdTokenFCM() async {
    return _getIntApplicationSavedInformation('idTokenFCM');
  }

  Future<String> getPreferredIdentity() async {
    return _getStringApplicationSavedInformation('identity');
  }

  Future<String> getPreferredPassword() async {
    return _getStringApplicationSavedInformation('password');
  }

  Future<bool> getPreferredIsBiometrics() async {
    return _getBoolApplicationSavedInformation('isBiometrics');
  }

  Future<bool> getPreferredIsLogin() async {
    return _getBoolApplicationSavedInformation('isLogin');
  }

  Future<bool> setPreferredResultToken(String resultTokenLogin) async {
    return _setStringApplicationSavedInformation(
        'resultTokenLogin', resultTokenLogin);
  }

  Future<bool> setPreferredToken(String token) async {
    return _setStringApplicationSavedInformation('token', token);
  }

  ///set token Firebase messaging cloud cho user
  Future<bool> setPreferredTokenFCM(String tokenFMC) async {
    return _setStringApplicationSavedInformation('tokenFCM', tokenFMC);
  }

  Future<bool> setPreferredIdTokenFCM(int idTokenFMC) async {
    return _setIntApplicationSavedInformation('idTokenFCM', idTokenFMC);
  }

  Future<bool> setPreferredIdentity(String username) async {
    return _setStringApplicationSavedInformation('identity', username);
  }

  Future<bool> setPreferredPassword(String password) async {
    return _setStringApplicationSavedInformation('password', password);
  }

  Future<bool> setPreferredIsBiometrics(bool enable) async {
    return _setBoolApplicationSavedInformation('isBiometrics', enable);
  }

  Future<bool> setPreferredIsLogin(bool isLogin) async {
    return _setBoolApplicationSavedInformation('isLogin', isLogin);
  }

  // ------------------ SINGLETON -----------------------
  static final TokenPreferences _preferences = TokenPreferences._internal();

  factory TokenPreferences() {
    return _preferences;
  }

  TokenPreferences._internal();
}

==> hqsoft_core-0.0.63.tar.gz: lib/core_base/preferences/token_login_preferences.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:hqsoft_core/data_base/data_base.dart';
import 'package:shared_preferences/shared_preferences.dart';

const String _storageKey = "TokenLogin_";

Future<SharedPreferences> _prefs = SharedPreferences.getInstance();

TokenPreferences tokenPreferences = TokenPreferences();

class TokenPreferences {
  /// ----------------------------------------------------------
  /// Generic routine to fetch a preference
  /// ----------------------------------------------------------
  Future<String> _getStringApplicationSavedInformation(String name) async {
    final SharedPreferences prefs = await _prefs;
    return prefs.getString(_storageKey + name) ?? '';
  }

  Future<bool> _getBoolApplicationSavedInformation(String name) async {
    final SharedPreferences prefs = await _prefs;

    return prefs.getBool(_storageKey + name) ?? false;
  }

  Future<int> _getIntApplicationSavedInformation(String name) async {
    final SharedPreferences prefs = await _prefs;
    return prefs.getInt(_storageKey + name) ?? -1;
  }

  Future<bool> _setStringApplicationSavedInformation(
      String name, String value) async {
    final SharedPreferences prefs = await _prefs;

    return prefs.setString(_storageKey + name, value);
  }

  Future<bool> _setBoolApplicationSavedInformation(
      String name, bool value) async {
    final SharedPreferences prefs = await _prefs;

    return prefs.setBool(_storageKey + name, value);
  }

  Future<bool> _setIntApplicationSavedInformation(
      String name, int value) async {
    final SharedPreferences prefs = await _prefs;
    return prefs.setInt(_storageKey + name, value);
  }

  setPreferredResultTokenLogin(ResultTokenLogin resultTokenLogin) async {
    await tokenPreferences
        .setPreferredResultToken(jsonEncode(resultTokenLogin));
    await tokenPreferences.setPreferredToken(resultTokenLogin.token.toString());
    await tokenPreferences.setPreferredIdentity(resultTokenLogin.identity.toString());
    await tokenPreferences.setPreferredPassword(resultTokenLogin.password.toString());
  }

  Future<ResultTokenLogin?> getPreferredResultToken() async {
    String resultTokenString = "";
    resultTokenString =
        await _getStringApplicationSavedInformation('resultTokenLogin');
    if (resultTokenString.length == 0) {
      return null;
    }
    ResultTokenLogin resultToken =
        ResultTokenLogin.fromJson(jsonDecode(resultTokenString));
    return resultToken;
  }

  Future<String> getPreferredToken() async {
    return _getStringApplicationSavedInformation('token');
  }

  Future<String> getPreferredTokenFCM() async {
    return _getStringApplicationSavedInformation('tokenFCM');
  }

  Future<int> getPreferredIdTokenFCM() async {
    return _getIntApplicationSavedInformation('idTokenFCM');
  }

  Future<String> getPreferredIdentity() async {
    return _getStringApplicationSavedInformation('identity');
  }

  Future<String> getPreferredPassword() async {
    return _getStringApplicationSavedInformation('password');
  }

  Future<bool> getPreferredIsBiometrics() async {
    return _getBoolApplicationSavedInformation('isBiometrics');
  }

  Future<bool> getPreferredIsLogin() async {
    return _getBoolApplicationSavedInformation('isLogin');
  }

  Future<bool> setPreferredResultToken(String resultTokenLogin) async {
    return _setStringApplicationSavedInformation(
        'resultTokenLogin', resultTokenLogin);
  }

  Future<bool> setPreferredToken(String token) async {
    return _setStringApplicationSavedInformation('token', token);
  }

  ///set token Firebase messaging cloud cho user
  Future<bool> setPreferredTokenFCM(String tokenFMC) async {
    return _setStringApplicationSavedInformation('tokenFCM', tokenFMC);
  }

  Future<bool> setPreferredIdTokenFCM(int idTokenFMC) async {
    return _setIntApplicationSavedInformation('idTokenFCM', idTokenFMC);
  }

  Future<bool> setPreferredIdentity(String username) async {
    return _setStringApplicationSavedInformation('identity', username);
  }

  Future<bool> setPreferredPassword(String password) async {
    return _setStringApplicationSavedInformation('password', password);
  }

  Future<bool> setPreferredIsBiometrics(bool enable) async {
    return _setBoolApplicationSavedInformation('isBiometrics', enable);
  }

  Future<bool> setPreferredIsLogin(bool isLogin) async {
    return _setBoolApplicationSavedInformation('isLogin', isLogin);
  }

  // ------------------ SINGLETON -----------------------
  static final TokenPreferences _preferences = TokenPreferences._internal();

  factory TokenPreferences() {
    return _preferences;
  }

  TokenPreferences._internal();
}
